@@ -1,8 +1,8 @@
 # -*- coding: utf-8 -*-
 
 # 设置管理域名 & 上传域名
-PUT_URL = 'apitest_user.up0.v1.wcsapi.com'
-MGR_URL = 'apitest_user.mgr0.v1.wcsapi.com'
+PUT_URL = 'user.up0.v1.wcsapi.com'
+MGR_URL = 'user.mgr0.v1.wcsapi.com'
 
 # 设置分片上传的块大小和片大小，单位均为字节
 _BLOCK_SIZE = 1024 * 1024 * 4
