@@ -21,25 +21,10 @@ class BucketManager(object):
             yield n
             n += 1
 
-    def make_download_url(self, key, param):
-        url = ['http://{0}/{1}'.format(self.host, key)]
-        if param:
-            paramlist = []
-            for k, v in param.items():
-                paramlist.append('{0}={1}'.format(k, v))
-            paramlist = '&'.join(paramlist)
-        url.append(paramlist)
-        url = '?'.join(url)
-        return url
-
     def gernerate_headers(self,url,body=None):
         token = self.auth.managertoken(url,body=body)
         headers = {'Authorization': token}
         return headers
-
-    def download(self, key, param):
-        url = self.make_down_url(key, param)
-        return _get(url=url)
     
     def make_delete_url(self, bucket, key):
         return 'http://{0}/delete/{1}'.format(self.host, entry(bucket, key))
@@ -64,11 +49,7 @@ class BucketManager(object):
     def make_list_url(self, param):
         url = ['http://{0}/list'.format(self.host)]
         if param:
-            paramlist = []
-            for k, v in param.items():
-                paramlist.append('{0}={1}'.format(k, v))
-            paramlist = '&'.join(paramlist)
-        url.append(paramlist)
+            url.append(self.params_parse(param))
         url = '?'.join(url)
         return url
     
@@ -96,10 +77,7 @@ class BucketManager(object):
         self.logger.info('The return code is %d and text of list request is: %s', code, text)
         return code, text
 
-    def fmgr_rename(self, bucket, key, key_to, force='false'):
-        pass
-
-    def params(self, params):
+    def params_parse(self, params):
         if params:
             paramlist = [] 
             for k, v in params.items():
@@ -114,7 +92,7 @@ class BucketManager(object):
             data['notifyURL'] = base64.b64encode(notifyurl)
         if separate is not None:
             data['separate'] = separate
-        reqdata = self.params(data)
+        reqdata = self.params_parse(data)
         self.logger.info('Move request body is: %s', reqdata)
         self.logger.info('Start to move file')
         code, text = _post(url=url, data=reqdata, headers=self.gernerate_headers(url, body=reqdata))
@@ -128,7 +106,7 @@ class BucketManager(object):
             data['notifyURL'] = base64.b64encode(notifyurl)
         if separate is not None:
             data['separate'] = separate
-        reqdata = self.params(data)
+        reqdata = self.params_parse(data)
         self.logger.info('Copy request body is: %s', reqdata)
         self.logger.info('Start to copy file')
         code, text = _post(url=url, data=reqdata,headers=self.gernerate_headers(url, body=reqdata))
