@@ -149,6 +149,7 @@ class SliceUpload(object):
          
         else:
             self.logger.info('Do not need to upload, all file blocks have been uplaod')
+
         results = self.recovery_from_record()
         if self.iscomplet(results):
             self.logger.info('Now all blocks have upload suc.')
@@ -156,7 +157,7 @@ class SliceUpload(object):
         else:
             fail_list = self.result_analysis(results)
             self.logger.info('Sorry, These block %s upload fail',fail_list )
-            return -1, "slice upload uncomplet" 
+            return -1, "slice upload fail" 
 
     def make_bput_post(self, ctx, bputnum, uploadBatch, bput_next):
         url = self.bput_url(ctx, bputnum*_BPUT_SIZE)
